@@ -35,8 +35,7 @@ from ..base import get_home_dir
 class _GlueDataset(TSVDataset):
     def __init__(self, root, data_file, **kwargs):
         root = os.path.expanduser(root)
-        if not os.path.isdir(root):
-            os.makedirs(root)
+        os.makedirs(root, exist_ok=True)
         segment, zip_hash, data_hash = data_file
         self._root = root
         filename = os.path.join(self._root, '%s.tsv' % segment)
